rho=2;
epsilon=0.001;

tspan=[0 16000];
phi=0.2;
y0=[phi 1];

odefn = @(t,y) [-y(1)*y(2) + rho*epsilon*(1-2*y(1))^2 ; -rho*y(1)*y(2)];

opts = odeset('maxstep',0.02);
sol = ode15s(odefn,tspan,y0);

tsw=epsilon^(-1)*rho^(-2)*(1-rho*phi);

%%

betI = @(tb) phi*(1-rho*phi)*exp((rho*phi-1)*tb)./(1-rho*phi*exp((rho*phi-1)*tb));
gamI = @(tb) rho*phi*(1-rho*phi)*exp((rho*phi-1)*tb)./(1-rho*phi*exp((rho*phi-1)*tb))-rho*phi+1;

betII = @(tb) epsilon*rho./(1-rho*phi-rho^2*epsilon*tb);
gamII = @(tb) 1-rho*phi-rho^2*epsilon*tb;

c3=0;
betIII = @(tb)     exp(-tb.*(rho^2*tb/2+c3)) ./ ( sqrt(pi/2)*exp(c3^2/2/rho^2)*(erf((rho^2*tb+c3)/rho/sqrt(2))+1) ) + rho*tb + c3/rho;
gamIII = @(tb) rho*exp(-tb.*(rho^2*tb/2+c3)) ./ ( sqrt(pi/2)*exp(c3^2/2/rho^2)*(erf((rho^2*tb+c3)/rho/sqrt(2))+1) );

betIV = @(tb) 1/2-1/2./(1+2*(phi-1/rho+rho*epsilon*tb));
gamIV = @(tb) 0*tb;

%%

figure(1);clf;hold on;
T=[tspan(1):0.02:tspan(end)];
plot(sol.x,sol.y(1,:),'b');
plot(T,betI(T),'b--');
plot(sol.x,sol.y(2,:),'r');
plot(T,gamI(T),'r--');
xlim([0 epsilon^(-1/2)]);
ylim([0 1.2]);
hx=xlabel('\tau');

hl=legend('\(\beta\) (numerical)','\(\beta\) (asymptotic I)','\(\gamma\) (numerical)','\(\gamma\) (asymptotic I)');
set(hl, 'interpreter','latex');
wd=7;
ht=5.5;
fs=8;
fn='times';
set(1,'paperunits','centimeters');
set(1,'papersize',[wd ht]);
set(1,'paperposition',[0 0 wd ht]);
set(gca,'fontsize',fs,'fontname',fn);
set(hl,'fontsize',fs,'fontname',fn);
set(hx,'fontsize',fs,'fontname',fn);
set(gca,'tickdir','out');
box on;
grid on;
print(1,'-dpdf','regionI.pdf');

%%

figure(2);clf;hold on;
hp=plot(betI(T),gamI(T),'k');
set(hp,'linewidth',2);
xlim([0 0.5]);
ylim([0 1]);
hx=xlabel('\(\beta\)','interpreter','latex');
hy=ylabel('\(\gamma\)','interpreter','latex');
wd=7;
ht=5.5;
fs=8;
fn='times';
set(2,'paperunits','centimeters');
set(2,'papersize',[wd ht]);
set(2,'paperposition',[0 0 wd ht]);
set(gca,'fontsize',fs,'fontname',fn);
set(hx,'fontsize',fs,'fontname',fn);
set(hy,'fontsize',fs,'fontname',fn);
box on;
grid on;
print(2,'-dpdf','regionIPhase.pdf');


%%

figure(1);clf;hold on;
plot(sol.x,sol.y(1,:),'b');
plot(T,betII(T),'b--');
plot(sol.x,sol.y(2,:),'r');
plot(T,gamII(T),'r--');
T=[tspan(1):0.02:tspan(end)];
xlim([0 (1-rho*phi)/(rho^2*epsilon)]);
ylim([0 1.2]);
hx=xlabel('\tau');

hl=legend('\(\beta\) (numerical)','\(\beta\) (asymptotic II)','\(\gamma\) (numerical)','\(\gamma\) (asymptotic II)');
set(hl, 'interpreter','latex');
wd=7;
ht=5.5;
fs=8;
fn='times';
set(1,'paperunits','centimeters');
set(1,'papersize',[wd ht]);
set(1,'paperposition',[0 0 wd ht]);
set(gca,'fontsize',fs,'fontname',fn);
set(hl,'fontsize',fs,'fontname',fn);
set(hx,'fontsize',fs,'fontname',fn);
set(gca,'tickdir','out');
box on;
grid on;
print(1,'-dpdf','regionII.pdf');

%%

figure(2)
T=[tspan(1):0.2:(1-rho*phi)/(rho^2*epsilon)-2*epsilon^(-1/2)];
hp=plot(betII(T),gamII(T),'m');
set(hp,'linewidth',2);
xlim([0 0.5]);
ylim([0 1]);
hx=xlabel('\(\beta\)','interpreter','latex');
hy=ylabel('\(\gamma\)','interpreter','latex');
wd=7;
ht=5.5;
fs=8;
fn='times';
set(2,'paperunits','centimeters');
set(2,'papersize',[wd ht]);
set(2,'paperposition',[0 0 wd ht]);
set(gca,'fontsize',fs,'fontname',fn);
set(hx,'fontsize',fs,'fontname',fn);
set(hy,'fontsize',fs,'fontname',fn);
box on;
grid on;
print(2,'-dpdf','regionIIPhase.pdf');


%%

figure(1);clf;hold on;

plot(sol.x,sol.y(1,:),'b');
plot(T,betIV(T),'b--');
plot(sol.x,sol.y(2,:),'r');
plot(T,gamIV(T),'r--');
T=[tspan(1):0.02:tspan(end)];
xlim([(1-rho*phi)/(rho^2*epsilon) (1-rho*phi)/(rho^2*epsilon)+1/epsilon]);
ylim([0 1.2]);
hx=xlabel('\tau');

hl=legend('\(\beta\) (numerical)','\(\beta\) (asymptotic IV)','\(\gamma\) (numerical)','\(\gamma\) (asymptotic IV)');
set(hl, 'interpreter','latex');
wd=7;
ht=5.5;
fs=8;
fn='times';
set(1,'paperunits','centimeters');
set(1,'papersize',[wd ht]);
set(1,'paperposition',[0 0 wd ht]);
set(gca,'fontsize',fs,'fontname',fn);
set(hl,'fontsize',fs,'fontname',fn);
set(hx,'fontsize',fs,'fontname',fn);
set(gca,'tickdir','out');
box on;
grid on;
print(1,'-dpdf','regionIV.pdf');
   
%%

figure(2);
T=[(1-rho*phi)/(rho^2*epsilon)+2*epsilon^(-1/2):0.2:tspan(end)];
hp=plot(betIV(T),gamIV(T),'c');
set(hp,'linewidth',2);
xlim([0 0.5]);
ylim([0 1]);
hx=xlabel('\(\beta\)','interpreter','latex');
hy=ylabel('\(\gamma\)','interpreter','latex');
wd=7;
ht=5.5;
fs=8;
fn='times';
set(2,'paperunits','centimeters');
set(2,'papersize',[wd ht]);
set(2,'paperposition',[0 0 wd ht]);
set(gca,'fontsize',fs,'fontname',fn);
set(hx,'fontsize',fs,'fontname',fn);
set(hy,'fontsize',fs,'fontname',fn);
box on;
grid on;
print(2,'-dpdf','regionIVPhase.pdf');
%%

figure(2);
T=[50:0.2:(1-rho*phi)/(rho^2*epsilon)+2*epsilon^(-1/2)];
hp=plot(epsilon^(1/2)*betIII(epsilon^(1/2)*TIII-epsilon^(-1/2)*(rho^(-2)-phi/rho)), ...
        epsilon^(1/2)*gamIII(epsilon^(1/2)*TIII-epsilon^(-1/2)*(rho^(-2)-phi/rho)),'g');
set(hp,'linewidth',2);
xlim([0 0.5]);
ylim([0 1]);
hx=xlabel('\(\beta\)','interpreter','latex');
hy=ylabel('\(\gamma\)','interpreter','latex');
wd=7;
ht=5.5;
fs=8;
fn='times';
set(2,'paperunits','centimeters');
set(2,'papersize',[wd ht]);
set(2,'paperposition',[0 0 wd ht]);
set(gca,'fontsize',fs,'fontname',fn);
set(hx,'fontsize',fs,'fontname',fn);
set(hy,'fontsize',fs,'fontname',fn);
box on;
grid on;
print(2,'-dpdf','regionIIIPhase.pdf');

%%

figure(1);clf;hold on;

plot(sol.x,sol.y(1,:),'b');
T=[tspan(1):0.02:tspan(end)];
plot(T,epsilon^(1/2)*betIII(epsilon^(1/2)*T-epsilon^(-1/2)*(rho^(-2)-phi/rho)),'b--');
plot(sol.x,sol.y(2,:),'r');
plot(T,epsilon^(1/2)*gamIII(epsilon^(1/2)*T-epsilon^(-1/2)*(rho^(-2)-phi/rho)),'r--');
xlim([(1-rho*phi)/(rho^2*epsilon)-2*epsilon^(-1/2) (1-rho*phi)/(rho^2*epsilon)+2*epsilon^(-1/2)]);
ylim([0 1.2]);
hx=xlabel('\tau');

hl=legend('\(\beta\) (numerical)','\(\beta\) (asymptotic III)','\(\gamma\) (numerical)','\(\gamma\) (asymptotic III)');
set(hl, 'interpreter','latex');
wd=7;
ht=5.5;
fs=8;
fn='times';
set(1,'paperunits','centimeters');
set(1,'papersize',[wd ht]);
set(1,'paperposition',[0 0 wd ht]);
set(gca,'fontsize',fs,'fontname',fn);
set(hl,'fontsize',fs,'fontname',fn);
set(hx,'fontsize',fs,'fontname',fn);
set(gca,'tickdir','out');
box on;
grid on;
print(1,'-dpdf','regionIII.pdf');

%%


% all regions combined: phase plot, log time plot

figure(1);clf;hold on;
T=[tspan(1):0.02:epsilon^(-1/2)];
hp=plot(betI(T),gamI(T),'k');set(hp,'linewidth',1);
xlim([0 0.5]);
ylim([0 1]);
T=[tspan(1):0.2:(1-rho*phi)/(rho^2*epsilon)-2*epsilon^(-1/2)];
hp=plot(betII(T),gamII(T),'m');set(hp,'linewidth',1);
T=[(1-rho*phi)/(rho^2*epsilon)-2*epsilon^(-1/2):0.2:(1-rho*phi)/(rho^2*epsilon)+2*epsilon^(-1/2)];
hp=plot(epsilon^(1/2)*betIII(epsilon^(1/2)*T-epsilon^(-1/2)*(rho^(-2)-phi/rho)),epsilon^(1/2)*gamIII(epsilon^(1/2)*T-epsilon^(-1/2)*(rho^(-2)-phi/rho)),'g');
set(hp,'linewidth',1);
T=[(1-rho*phi)/(rho^2*epsilon)+2*epsilon^(-1/2):0.2:tspan(end)];
hp=plot(betIV(T),gamIV(T),'c');set(hp,'linewidth',1);
hx=xlabel('\(\beta\)' ,'interpreter','latex');set(hx,'fontsize',fs,'fontname',fn);
hy=ylabel('\(\gamma\)','interpreter','latex');set(hy,'fontsize',fs,'fontname',fn);
hl=legend('I','II','III','IV');
wd=9;
ht=5.5;
fs=8;
fn='times';
set(1,'paperunits','centimeters');
set(1,'papersize',[wd ht]);
set(1,'paperposition',[0 0 wd ht]);
set(gca,'fontsize',fs,'fontname',fn);
set(hl,'fontsize',fs,'fontname',fn);
set(hl,'box','off');
set(hl, 'interpreter','latex');
box on;
grid on;
set(gca,'tickdir','out');
print(1,'-dpdf','regionsPhase.pdf');




%%

% all regions combined: phase plot, log time plot

figure(1);clf;
% TI=[0.1:0.01:epsilon^(-1)];
% TII=[1:0.1:(1-rho*phi)/(rho^2*epsilon)-2*epsilon^(-1/2)];
% TIII=[(1-rho*phi)/(rho^2*epsilon)-2*epsilon^(-1/2):0.2:(1-rho*phi)/(rho^2*epsilon)+2*epsilon^(-1/2)];
% TIV=[(1-rho*phi)/(rho^2*epsilon)+2*epsilon^(-1/2):0.2:tspan(end)];

TI=[0.01:0.01:20];
TII=[5:0.1:100];
TIII=[50:0.2:(1-rho*phi)/(rho^2*epsilon)+2*epsilon^(-1/2)];
TIV=[(1-rho*phi)/(rho^2*epsilon)+2*epsilon^(-1/2):0.2:tspan(end)];

hp=semilogx(TI,betI(TI),'k',TII,betII(TII),'m', ...
    TIII,epsilon^(1/2)*betIII(epsilon^(1/2)*TIII-epsilon^(-1/2)*(rho^(-2)-phi/rho)),'g', ...
    TIV,betIV(TIV),'c');
set(hp,'linewidth',1);
xlim([0.01 1e5])
ylim([0 1]);
hx=xlabel('\(\tau\)' ,'interpreter','latex');set(hx,'fontsize',fs,'fontname',fn);
hy=ylabel('\(\beta\)','interpreter','latex');set(hy,'fontsize',fs,'fontname',fn);
hl=legend('I','II','III','IV');
wd=9;
ht=5.5;
fs=8;
fn='times';
set(1,'paperunits','centimeters');
set(1,'papersize',[wd ht]);
set(1,'paperposition',[0 0 wd ht]);
set(gca,'fontsize',fs,'fontname',fn);
set(hl,'fontsize',fs,'fontname',fn);
set(hl,'box','off');
set(hl, 'interpreter','latex');
box on;
grid on;
set(gca,'tickdir','out');
print(1,'-dpdf','regionsBetaVSTime.pdf');

%%

figure(1);clf;
% TI=[0.1:0.01:epsilon^(-1/2)];
% TII=[1:0.1:(1-rho*phi)/(rho^2*epsilon)-2*epsilon^(-1/2)];
% TIII=[(1-rho*phi)/(rho^2*epsilon)-2*epsilon^(-1/2):0.2:(1-rho*phi)/(rho^2*epsilon)+2*epsilon^(-1/2)];
% TIV=[(1-rho*phi)/(rho^2*epsilon)+2*epsilon^(-1/2):0.2:tspan(end)];


TI=[0.01:0.01:20];
TII=[5:0.1:100];
TIII=[50:0.2:(1-rho*phi)/(rho^2*epsilon)+2*epsilon^(-1/2)];
TIV=[(1-rho*phi)/(rho^2*epsilon)+2*epsilon^(-1/2):0.2:tspan(end)];

hp=semilogx(TI,gamI(TI),'k',TII,gamII(TII),'m', ...
    TIII,epsilon^(1/2)*gamIII(epsilon^(1/2)*TIII-epsilon^(-1/2)*(rho^(-2)-phi/rho)),'g', ...
    TIV,gamIV(TIV),'c');
set(hp,'linewidth',1);
xlim([0.01 1e5])
ylim([0 1]);
hx=xlabel('\(\tau\)' ,'interpreter','latex');set(hx,'fontsize',fs,'fontname',fn);
hy=ylabel('\(\gamma\)','interpreter','latex');set(hy,'fontsize',fs,'fontname',fn);
hl=legend('I','II','III','IV');
wd=9;
ht=5.5;
fs=8;
fn='times';
set(1,'paperunits','centimeters');
set(1,'papersize',[wd ht]);
set(1,'paperposition',[0 0 wd ht]);
set(gca,'fontsize',fs,'fontname',fn);
set(hl,'fontsize',fs,'fontname',fn);
set(hl,'box','off');
set(hl, 'interpreter','latex');
box on;
grid on;
set(gca,'tickdir','out');
print(1,'-dpdf','regionsGammaVSTime.pdf');