% plot switchover results and fit parameters

clear all;

% load experimental data
varyC=xlsread('variableC_resub.xlsx');
varyI=xlsread('variableI_resub.xlsx');

modelfn2 = @(c0,m0,k0,phi) (c0-phi*m0)./(k0*m0.^2);
costseries2 = @(k0,phi,c0,m0,tsw) sum((tsw-modelfn2(c0,m0,k0,phi)).^2);
costfn2 = @(params) costseries2(params(1),params(2),varyC(:,1),varyC(:,2),varyC(:,3))+...
                    costseries2(params(1),params(2),varyC(:,1),varyC(:,2),varyC(:,4))+...
                    costseries2(params(1),params(2),varyI(:,1),varyI(:,2),varyI(:,3))+...
                    costseries2(params(1),params(2),varyI(:,1),varyI(:,2),varyI(:,4));
params=fminsearch(costfn2,[1,0.2])
k0=params(1);
phi=params(2);

figure(1);clf;hold on;
wd=6.5;
ht=6;
fs=8;
fn='times';
set(1,'paperunits','centimeters');
set(1,'papersize',[wd ht]);
set(1,'paperposition',[0 0 wd ht]);
hp=plot(varyC(:,1),varyC(:,3),'bo');set(hp,'markersize',3);
hp=plot(varyC(:,1),varyC(:,4),'bo');set(hp,'markersize',3);
m=varyC(1,2);
c=linspace(min(varyC(:,1)),max(varyC(:,1)),100);plot(c,c./(k0*m^2),'r');
hx=xlabel('\(c_0\) (mol/l)' ,'interpreter','latex');set(hx,'fontsize',fs,'fontname',fn);
hy=ylabel('\(t_{\mathrm{sw}}\) (s)','interpreter','latex');set(hy,'fontsize',fs,'fontname',fn);
xlim([0 0.0075]);
ylim([0 275]);
set(gca,'tickdir','out');
box on;
print(1,'-dpdf','-r600','exptsA_resub.pdf');

figure(2);clf;hold on;
wd=6.5;
ht=6;
fs=8;
fn='times';
set(2,'paperunits','centimeters');
set(2,'papersize',[wd ht]);
set(2,'paperposition',[0 0 wd ht]);
hp=plot(varyI(:,2),varyI(:,3),'bo');set(hp,'markersize',3);
hp=plot(varyI(:,2),varyI(:,4),'bo');set(hp,'markersize',3);
c=varyI(1,1);
m=linspace(min(varyI(:,2)),max(varyI(:,2)),100);plot(m,c./(k0*m.^2),'r');
hx=xlabel('\(m_0\) (mol/l)' ,'interpreter','latex');set(hx,'fontsize',fs,'fontname',fn);
hy=ylabel('\(t_{\mathrm{sw}}\) (s)','interpreter','latex');set(hy,'fontsize',fs,'fontname',fn);
xlim([0.002 0.014]);
ylim([0 525]);
set(gca,'tickdir','out');
box on;
print(2,'-dpdf','-r600','exptsB_resub.pdf');

%%

figure(3);clf;
Nk=400;
Nphi=300;
k0array=linspace(0.4,0.7,Nk);
phiarray=linspace(-0.1,0.3,Nphi);
[K0,Phi]=meshgrid(k0array,phiarray);
for k=1:Nk
    for j=1:Nphi
        costPlot(j,k)=costfn2([K0(j,k),Phi(j,k)]);
    end
end
pcolor(K0,Phi,costPlot);
shading flat;
xlabel('\(k_0\)','interpreter','latex');
ylabel('\(\phi\)','interpreter','latex');

colorbar;


